==> magic3_1.5.3_src.tar.gz: magic3/widgets/admin_main/include/help/index.php <==
<?php
/**
 * ヘルプリソースファイル
 * index.php
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: index.php 822 2008-07-10 05:34:05Z fishbone $
 * @link       http://www.magic3.org
 */
// 直接アクセスの防止
defined('M3_SYSTEM') or die('Access error: Direct access denied.');

global $HELP;

// ########## ユーザ一覧 ##########
$HELP['userlist']['title'] = 'ユーザ一覧';
$HELP['userlist']['body'] = 'システムで一元管理するユーザの一覧です。';
$HELP['userlist_check']['title'] = '選択用チェックボックス';
$HELP['userlist_check']['body'] = '編集や削除を行う項目を選択します。';
$HELP['userlist_account']['title'] = 'ユーザアカウント';
$HELP['userlist_account']['body'] = 'ログイン時に使用するアカウントです。<br>メールアドレス形式のアカウントも使用できます。';
$HELP['userlist_pwd']['title'] = 'ユーザパスワード';
$HELP['userlist_pwd']['body'] = 'ログイン時に使用するパスワードです。';
$HELP['userlist_name']['title'] = '名前';
$HELP['userlist_name']['body'] = '画面上に表示されるユーザの名前です。';
$HELP['userlist_usertype']['title'] = 'ユーザ種別';
$HELP['userlist_usertype']['body'] = '管理者 - 管理機能にログインできます。<br>一般 - 管理機能以外の機能にログインできます。<br>仮登録 - 一般機能からユーザ登録を行い、まだログインしていないユーザです。一度ログインすると一般ユーザに変更されます。';
$HELP['userlist_admin']['title'] = '管理権限';
$HELP['userlist_admin']['body'] = '管理画面にアクセス可能かどうかの設定です。<br>チェックが入っているとアクセス可能です。';
$HELP['userlist_login']['title'] = 'ログイン可';
$HELP['userlist_login']['body'] = 'ログインを許可するかどうかの設定です。<br>チェックが入っているとログイン可能です。';
$HELP['userlist_new_btn']['title'] = '新規ボタン';
$HELP['userlist_new_btn']['body'] = '新規ユーザを追加します。';
$HELP['userlist_edit_btn']['title'] = '編集ボタン';
$HELP['userlist_edit_btn']['body'] = '選択されているユーザを編集します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_del_btn']['title'] = '削除ボタン';
$HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_ret_btn']['title'] = '戻るボタン';
$HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';
// ########## 画面作成 ##########
$HELP['pagedef_page_id']['title'] = 'ページID';
$HELP['pagedef_page_id']['body'] = 'ページを定義するためのIDです。IDはURLに付加されます。非公開項目は管理権限のない一般ユーザには公開されないページです。';
$HELP['pagedef_page_sub_id']['title'] = 'ページサブID';
$HELP['pagedef_page_sub_id']['body'] = 'ページを定義するための補助IDです。IDはURLに付加されます。';
$HELP['pagedef_preview_url']['title'] = 'URL';
$HELP['pagedef_preview_url']['body'] = 'プレビューに表示しているページへのURLです。';
$HELP['pagedef_detail_btn']['title'] = '詳細ボタン';
$HELP['pagedef_detail_btn']['body'] = 'ページ定義の詳細を表示します。';
$HELP['pagedef_default_template']['title'] = 'デフォルトテンプレート';
$HELP['pagedef_default_template']['body'] = 'デフォルトで設定されるデザインテンプレートを指定します。';
$HELP['pagedef_change_template_btn']['title'] = 'テンプレート変更';
$HELP['pagedef_change_template_btn']['body'] = 'デフォルトのテンプレートを変更します。';
$HELP['pagedef_template_img']['title'] = 'テンプレート表示イメージ';
$HELP['pagedef_template_img']['body'] = 'テンプレートを設定した場合の画面の表示イメージです。';
$HELP['pagedef_widget']['title'] = 'ウィジェット';
$HELP['pagedef_widget']['body'] = 'レイアウトに配置可能なウィジェットです。シングルクリックで取得し、画面レイアウト領域に配置します。';
$HELP['pagedef_layout']['title'] = '画面レイアウト';
$HELP['pagedef_layout']['body'] = '(ウィジェットの配置)<br>テンプレートにウィジェットを配置し、画面を作成します。ウィジェット一覧からマウスドラッグでウィジェットを取り出します。レイアウト画面の任意のポジション位置にドロップするとウィジェットが配置できます。レイアウト画面からウィジェットを削除するには、削除するウィジェットの右上のクローズボックスをクリックします。一度ドロップしたウィジェットは、ドラッグドロップで移動が可能です。<br>(ウィジェットコンテキストメニュー)<br>ウィジェットをマウス右クリックするとコンテキストメニューが表示されます。ウィジェットの設定を行ったり、ウィジェットの削除を行います。「ページ共通」属性を設定すると、ページに関わらず常にウィジェットが表示できます。(赤色表示)';
$HELP['pagedef_preview']['title'] = 'レイアウトとプレビューの切り替えボタン';
$HELP['pagedef_preview']['body'] = 'ウィジェットの配置を行うレイアウト画面と、実際に表示されるプレビュー画面を切り替えます。';
$HELP['pagedef_refresh']['title'] = '画面再表示';
$HELP['pagedef_refresh']['body'] = 'レイアウトまたはプレビュー画面を再表示します。';
$HELP['pagedef_preview_other']['title'] = '別画面でプレビュー';
$HELP['pagedef_preview_other']['body'] = '実際に表示される画面を別ウィンドウで表示します。';
$HELP['pagedef_position_block']['title'] = 'ポジションブロック名';
$HELP['pagedef_position_block']['body'] = 'デザインテンプレート内でのウィジェットの配置ブロックを指定します。';
$HELP['pagedef_position_index']['title'] = '表示順';
$HELP['pagedef_position_index']['body'] = 'ポジションブロック内でのウィジェットの表示順を指定します。';
$HELP['pagedef_widget_def_id']['title'] = '定義ID';
$HELP['pagedef_widget_def_id']['body'] = '個別のウィジェットの設定IDです。設定が必要な場合のみ設定可能になります。';
$HELP['pagedef_widget_visible']['title'] = 'ウィジェット表示制御';
$HELP['pagedef_widget_visible']['body'] = 'ウィジェットの表示、非表示を制御します。';
$HELP['pagedef_widget_common']['title'] = 'ページ共通属性';
$HELP['pagedef_widget_common']['body'] = '同ページIDで、サブページIDに関わらずウィジェットを表示するかどうかを指定します。';

// ########## テーブルデータ編集 ##########
$HELP['edittable_new_btn']['title'] = '新規ボタン';
$HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
$HELP['edittable_edit_btn']['title'] = '編集ボタン';
$HELP['edittable_edit_btn']['body'] = '選択されているレコードを編集します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_del_btn']['title'] = '削除ボタン';
$HELP['edittable_del_btn']['body'] = '選択されているレコードを削除します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_ret_btn']['title'] = '戻るボタン';
$HELP['edittable_ret_btn']['body'] = 'レコード一覧へ戻ります。';
?>

==> magic3_1.5.10_src.tar.gz: magic3/widgets/admin_main/include/help/index.php <==
<?php
/**
 * ヘルプリソースファイル
 * index.php
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: index.php 915 2008-08-14 08:30:00Z fishbone $
 * @link       http://www.magic3.org
 */
// 直接アクセスの防止
defined('M3_SYSTEM') or die('Access error: Direct access denied.');

global $HELP;

// ########## ユーザ一覧 ##########
$HELP['userlist']['title'] = 'ユーザ一覧';
$HELP['userlist']['body'] = 'システムで一元管理するユーザの一覧です。';
$HELP['userlist_check']['title'] = '選択用チェックボックス';
$HELP['userlist_check']['body'] = '編集や削除を行う項目を選択します。';
$HELP['userlist_account']['title'] = 'ユーザアカウント';
$HELP['userlist_account']['body'] = 'ログイン時に使用するアカウントです。<br>メールアドレス形式のアカウントも使用できます。';
$HELP['userlist_pwd']['title'] = 'ユーザパスワード';
$HELP['userlist_pwd']['body'] = 'ログイン時に使用するパスワードです。';
$HELP['userlist_name']['title'] = '名前';
$HELP['userlist_name']['body'] = '画面上に表示されるユーザの名前です。';
$HELP['userlist_usertype']['title'] = 'ユーザ種別';
$HELP['userlist_usertype']['body'] = '管理者 - 管理機能にログインできます。<br>一般 - 管理機能以外の機能にログインできます。<br>仮登録 - 一般機能からユーザ登録を行い、まだログインしていないユーザです。一度ログインすると一般ユーザに変更されます。';
$HELP['userlist_admin']['title'] = '管理権限';
$HELP['userlist_admin']['body'] = '管理画面にアクセス可能かどうかの設定です。<br>チェックが入っているとアクセス可能です。';
$HELP['userlist_login']['title'] = 'ログイン可';
$HELP['userlist_login']['body'] = 'ログインを許可するかどうかの設定です。<br>チェックが入っているとログイン可能です。';
$HELP['userlist_new_btn']['title'] = '新規ボタン';
$HELP['userlist_new_btn']['body'] = '新規ユーザを追加します。';
$HELP['userlist_edit_btn']['title'] = '編集ボタン';
$HELP['userlist_edit_btn']['body'] = '選択されているユーザを編集します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_del_btn']['title'] = '削除ボタン';
$HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_ret_btn']['title'] = '戻るボタン';
$HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';
// ########## 画面作成 ##########
$HELP['pagedef_page_id']['title'] = 'ページID';
$HELP['pagedef_page_id']['body'] = 'ページを定義するためのIDです。IDはURLに付加されます。非公開項目は管理権限のない一般ユーザには公開されないページです。';
$HELP['pagedef_page_sub_id']['title'] = 'ページサブID';
$HELP['pagedef_page_sub_id']['body'] = 'ページを定義するための補助IDです。IDはURLに付加されます。';
$HELP['pagedef_preview_url']['title'] = 'URL';
$HELP['pagedef_preview_url']['body'] = 'プレビューに表示しているページへのURLです。';
$HELP['pagedef_detail_btn']['title'] = '詳細ボタン';
$HELP['pagedef_detail_btn']['body'] = 'ページ定義の詳細を表示します。';
$HELP['pagedef_default_template']['title'] = 'デフォルトテンプレート';
$HELP['pagedef_default_template']['body'] = 'デフォルトで設定されるデザインテンプレートを指定します。';
$HELP['pagedef_change_template_btn']['title'] = 'テンプレート変更';
$HELP['pagedef_change_template_btn']['body'] = 'デフォルトのテンプレートを変更します。';
$HELP['pagedef_template_img']['title'] = 'テンプレート表示イメージ';
$HELP['pagedef_template_img']['body'] = 'テンプレートを設定した場合の画面の表示イメージです。';
$HELP['pagedef_widget']['title'] = 'ウィジェット';
$HELP['pagedef_widget']['body'] = 'レイアウトに配置可能なウィジェットです。シングルクリックで取得し、画面レイアウト領域に配置します。';
$HELP['pagedef_layout']['title'] = '画面レイアウト';
$HELP['pagedef_layout']['body'] = '(ウィジェットの配置)<br>テンプレートにウィジェットを配置し、画面を作成します。ウィジェット一覧からマウスドラッグでウィジェットを取り出します。レイアウト画面の任意のポジション位置にドロップするとウィジェットが配置できます。レイアウト画面からウィジェットを削除するには、削除するウィジェットの右上のクローズボックスをクリックします。一度ドロップしたウィジェットは、ドラッグドロップでページ上の移動が可能です。最大化ボタンまたはESCキーでレイアウト画面が最大化できます。最大化状態から元に戻るにはESCキーを押します。<br>(ウィジェットコンテキストメニュー)<br>ウィジェットをマウス右クリックするとコンテキストメニューが表示されます。ウィジェットの設定を行ったり、ウィジェットの削除を行います。「ページ共通」属性を設定したウィジェットは、ページに関わらず常に表示されます。(赤色表示)';
$HELP['pagedef_preview']['title'] = 'レイアウトとプレビューの切り替えボタン';
$HELP['pagedef_preview']['body'] = 'ウィジェットの配置を行うレイアウト画面と、実際に表示されるプレビュー画面を切り替えます。';
$HELP['pagedef_refresh']['title'] = '画面再表示';
$HELP['pagedef_refresh']['body'] = 'レイアウトまたはプレビュー画面を再表示します。';
$HELP['pagedef_preview_other']['title'] = '別画面でプレビュー';
$HELP['pagedef_preview_other']['body'] = '実際に表示される画面を別ウィンドウで表示します。';
$HELP['pagedef_position_block']['title'] = 'ポジションブロック名';
$HELP['pagedef_position_block']['body'] = 'デザインテンプレート内でのウィジェットの配置ブロックを指定します。';
$HELP['pagedef_position_index']['title'] = '表示順';
$HELP['pagedef_position_index']['body'] = 'ポジションブロック内でのウィジェットの表示順を指定します。';
$HELP['pagedef_widget_def_id']['title'] = '定義ID';
$HELP['pagedef_widget_def_id']['body'] = '個別のウィジェットの設定IDです。設定が必要な場合のみ設定可能になります。';
$HELP['pagedef_widget_visible']['title'] = 'ウィジェット表示制御';
$HELP['pagedef_widget_visible']['body'] = 'ウィジェットの表示、非表示を制御します。';
$HELP['pagedef_widget_common']['title'] = 'ページ共通属性';
$HELP['pagedef_widget_common']['body'] = '同ページIDで、サブページIDに関わらずウィジェットを表示するかどうかを指定します。';

// ########## テーブルデータ編集 ##########
$HELP['edittable_new_btn']['title'] = '新規ボタン';
$HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
$HELP['edittable_edit_btn']['title'] = '編集ボタン';
$HELP['edittable_edit_btn']['body'] = '選択されているレコードを編集します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_del_btn']['title'] = '削除ボタン';
$HELP['edittable_del_btn']['body'] = '選択されているレコードを削除します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_ret_btn']['title'] = '戻るボタン';
$HELP['edittable_ret_btn']['body'] = 'レコード一覧へ戻ります。';
?>
